<?php

/**
 * This is the model class for table "pc_regulators".
 *
 * The followings are the available columns in table 'pc_regulators':
 * @property integer $pcrg_id
 * @property string $pcrg_store_name
 * @property string $pcrg_fname
 * @property string $pcrg_lname
 * @property string $pcrg_email
 * @property string $pcr_opensource
 * @property string $pcrg_mobile_number
 * @property integer $pcrg_status
 * @property string $pcrg_address
 * @property double $pcrg_charges
 * @property string $pcrg_created_at
 * @property string $pcrg_updated_at
 */
class Regulators extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_regulators';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			
			array('pcrg_store_name, pcrg_fname, pcrg_lname,pcrg_address, pcrg_email, pcrg_mobile_number,pcrg_charges, pcrg_status', 'required','on'=>'update,addRegulators,updateRegulators'),
			array('pcrg_status', 'numerical', 'integerOnly'=>true,'on'=>'update,addRegulators,updateRegulators'),
			array('pcrg_store_name, pcrg_fname, pcrg_lname, pcrg_email, pcrg_mobile_number', 'length', 'max'=>32,'on'=>'update,addRegulators,updateRegulators'),
			
			array('pcrg_id, pcrg_store_name, pcrg_fname,pcrg_address, pcrg_lname, pcrg_charges,pcrg_email, pcrg_mobile_number, pcrg_status, pcrg_created_at, pcrg_updated_at', 'safe', 'on'=>'search,update,addRegulators,updateRegulators'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcrg_id' => 'Pcrg',
			'pcrg_store_name' => 'Bank Name',
			'pcrg_fname' => 'Fname',
			'pcrg_lname' => 'Lname',
			'pcrg_email' => 'Email',
			'pcr_opensource' => 'Pcr Opensource',
			'pcrg_mobile_number' => 'Mobile Number',
			'pcrg_status' => 'Status',
			'pcrg_address' => 'Address',
			'pcrg_charges' => 'Charges',
			'pcrg_created_at' => 'Created At',
			'pcrg_updated_at' => 'Updated At',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function admin_regulator_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('pcrg_id',$this->pcrg_id);
		$criteria->compare('pcrg_store_name',$this->pcrg_store_name,true);
		$criteria->compare('pcrg_fname',$this->pcrg_fname,true);
		$criteria->compare('pcrg_lname',$this->pcrg_lname,true);
		$criteria->compare('pcrg_email',$this->pcrg_email,true);
		$criteria->compare('pcr_opensource',$this->pcr_opensource,true);
		$criteria->compare('pcrg_mobile_number',$this->pcrg_mobile_number,true);
		$criteria->compare('pcrg_status',$this->pcrg_status);
		$criteria->compare('pcrg_address',$this->pcrg_address,true);
		$criteria->compare('pcrg_charges',$this->pcrg_charges);
		$criteria->compare('pcrg_created_at',$this->pcrg_created_at,true);
		$criteria->compare('pcrg_updated_at',$this->pcrg_updated_at,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			 'sort'=>array(
                        'defaultOrder'=>'pcrg_id DESC',
                    ),
		));
	}

	public function beforeSave(){
		if($this->isNewRecord)
			$this->pcrg_created_at	= date('Y-m-d H:i:s');
		else
			$this->pcrg_updated_at	= date('Y-m-d H:i:s');

		return true;
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Regulators the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
