<?php

/**
 * This is the model class for table "pc_transactions".
 *
 * The followings are the available columns in table 'pc_transactions':
 * @property integer $pct_id
 * @property string $pct_transaction_id
 * @property integer $pct_userid
 * @property integer $pct_transaction_status
 * @property integer $pct_transaction_mode
 * @property string $pct_transaction_date
 * @property string $pct_referece_no
 * @property string $pct_transaction_message
 * @property double $pct_transaction_amount
 * @property double $pct_transaction_charge
 * @property integer $pct_transaction_type
 * @property integer $pct_refund_status
 * @property string $pct_bank_card_name
 * @property string $pct_ref_id
 * @property string $added_at
 * @property string $updated_at
 */
class Transactions extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_transactions';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('pct_transaction_status', 'required','on'=>'updateTrans'),
			
			array('pct_id, pct_transaction_id, pct_userid, pct_transaction_status, pct_transaction_mode, pct_transaction_date, pct_referece_no, pct_transaction_message, pct_transaction_amount,pct_ref_id, pct_transaction_charge, pct_transaction_type, pct_refund_status, pct_bank_card_name, added_at, updated_at', 'safe', 'on'=>'admin_transactions_search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'UserRel' => array(self::BELONGS_TO, 'Userdetails', 'pct_userid'),
			'TransRel' => array(PaysuhOrderData::BELONGS_TO, 'Transactions', 'pct_ref_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pct_id' => 'Pct',
			'pct_transaction_id' => 'Transaction ID',
			'pct_userid' => 'Transaction Email',
			'pct_transaction_status' => 'Transaction Status',
			'pct_transaction_mode' => 'Transaction Mode',
			'pct_transaction_date' => 'Transaction Date',
			'pct_referece_no' => 'Auth Code',
			'pct_transaction_message' => 'Transaction Message',
			'pct_transaction_amount' => 'Transaction Amount('.CURRENCY.')',
			'pct_transaction_charge' => 'Transaction Charge('.CURRENCY.')',
			'pct_transaction_type' => 'Transaction Type',
			'pct_refund_status' => 'Refund Status',
			'pct_bank_card_name' => 'Bank or Card Name',
			'added_at' => 'Added At',
			'updated_at' => 'Updated At',
		);
	}

	
	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function admin_transactions_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;
		$criteria->with = array('UserRel','TransRel');
		$criteria->together = true;

		$criteria->compare('pct_id',$this->pct_id);
		$criteria->compare('pct_transaction_id',$this->pct_transaction_id,true);
		$criteria->compare('pct_userid',$this->pct_userid);
		$criteria->compare('pct_transaction_status',$this->pct_transaction_status);
		$criteria->compare('pct_transaction_mode',$this->pct_transaction_mode);
		$criteria->compare('pct_transaction_date',$this->pct_transaction_date,true);
		$criteria->compare('pct_referece_no',$this->pct_referece_no,true);
		$criteria->compare('pct_transaction_message',$this->pct_transaction_message,true);
		$criteria->compare('pct_transaction_amount',$this->pct_transaction_amount);
		$criteria->compare('pct_transaction_charge',$this->pct_transaction_charge);
		if(isset($_GET['type']) && $_GET['type']){

			$criteria->compare('TransRel.pct_transaction_type',$_GET['type']);
		} else
		{
			$criteria->compare('pct_transaction_type',$this->pct_transaction_type);
		}
		$criteria->compare('pct_refund_status',$this->pct_refund_status);
		$criteria->compare('pct_bank_card_name',$this->pct_bank_card_name,true);
		$criteria->compare('added_at',$this->added_at,true);
		$criteria->compare('updated_at',$this->updated_at,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'TransRel.pct_id DESC',
                    ),
		));
	}
	public function user_transactions_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.
		
		$criteria=new CDbCriteria;
		
		$criteria->compare('pct_id',$this->pct_id);
		$criteria->compare('pct_transaction_id',$this->pct_transaction_id,true);
		$criteria->compare('pct_transaction_status',$this->pct_transaction_status);
		$criteria->compare('pct_transaction_mode',$this->pct_transaction_mode);
		$criteria->compare('pct_transaction_date',$this->pct_transaction_date,true);
		$criteria->compare('pct_referece_no',$this->pct_referece_no,true);
		$criteria->compare('pct_transaction_message',$this->pct_transaction_message,true);
		$criteria->compare('pct_transaction_amount',$this->pct_transaction_amount);
		$criteria->compare('pct_transaction_charge',$this->pct_transaction_charge);
		$criteria->compare('pct_userid',Yii::app()->user->getState('Userid'),true);
		$criteria->compare('pct_transaction_type',$this->pct_transaction_type);
		$criteria->compare('pct_refund_status',$this->pct_refund_status);
		$criteria->compare('pct_bank_card_name',$this->pct_bank_card_name,true);
		$criteria->compare('added_at',$this->added_at,true);
		$criteria->compare('updated_at',$this->updated_at,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pct_id DESC',
                    ),
		));
	}

	public function beforeSave(){
		if($this->isNewRecord){
			$this->added_at	= date('Y-m-d H:i:s');
			$this->pct_transaction_date	= date('Y-m-d H:i:s');
		} else
			$this->updated_at	= date('Y-m-d H:i:s');

		return true;
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Transactions the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	
}
