<?php

/**
 * This is the model class for table "pc_withdraw_fee".
 *
 * The followings are the available columns in table 'pc_withdraw_fee':
 * @property integer $pcwf_id
 * @property string $pcwf_name
 * @property string $pcwf_process_time
 * @property double $pcwf_value
 * @property double $pcwf_percentage
 * @property integer $pcwf_status
 */
class WithdrawFee extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_withdraw_fee';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('pcwf_name', 'unique'),
			array('pcwf_name, pcwf_process_time', 'required'),
			array('pcwf_name', 'length', 'max'=>255),
			array('pcwf_process_time', 'length', 'max'=>32),
			array('pcwf_id, pcwf_name, pcwf_process_time, pcwf_value, pcwf_percentage, pcwf_status', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcwf_id' => 'Pcwf',
			'pcwf_name' => 'Name',
			'pcwf_process_time' => 'Time',
			'pcwf_value' => 'Value (JMD)',
			'pcwf_percentage' => 'Percentage (%)',
			'pcwf_status' => 'Status',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('pcwf_id',$this->pcwf_id);
		$criteria->compare('pcwf_name',$this->pcwf_name,true);
		$criteria->compare('pcwf_process_time',$this->pcwf_process_time,true);
		$criteria->compare('pcwf_value',$this->pcwf_value);
		$criteria->compare('pcwf_percentage',$this->pcwf_percentage);
		$criteria->compare('pcwf_status',$this->pcwf_status);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcwf_id DESC',
                    ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return WithdrawFee the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
